atomate.feff.firetasks.tests package — atomate 0.9.2 documentation

# atomate.feff.firetasks.tests package

## Submodules

## atomate.feff.firetasks.tests.test_tasks module

class `atomate.feff.firetasks.tests.test_tasks.` `TestTasks`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_copy_feff_outputs_task`()
  `test_write_paths_task`()

## Module contents